@@ -4,7 +4,8 @@ use base qw/Class::Data::Inheritable/;
 use strict;
 use warnings;
 
-use NEXT;
+use MRO::Compat;
+use mro 'c3';
 use Scalar::Util ();
 use Catalyst::Plugin::Authorization::ACL::Engine;
 
@@ -13,15 +14,13 @@ use Catalyst::Plugin::Authorization::ACL::Engine;
 
 BEGIN { __PACKAGE__->mk_classdata("_acl_engine") }
 
-our $VERSION = '0.09';
+our $VERSION = '0.11';
 
 my $FORCE_ALLOW = bless {}, __PACKAGE__ . "::Exception";
 
 sub execute {
     my ( $c, $class, $action ) = @_;
 
-    local $NEXT::NEXT{ $c, "execute" };
-
     if (    Scalar::Util::blessed($action)
         and $action->name ne "access_denied"
         and $action->name ne "ACL error rethrower" )
@@ -38,7 +37,7 @@ sub execute {
 
     }
 
-    $c->NEXT::execute( $class, $action );
+    $c->maybe::next::method( $class, $action );
 }
 
 sub acl_allow_root_internals {
@@ -51,7 +50,7 @@ sub acl_allow_root_internals {
 
 sub setup_actions {
     my $app = shift;
-    my $ret = $app->NEXT::setup_actions(@_);
+    my $ret = $app->maybe::next::method(@_);
 
     $app->_acl_engine(
         Catalyst::Plugin::Authorization::ACL::Engine->new($app) );
@@ -104,12 +103,16 @@ sub acl_add_rule {
 sub acl_access_denied {
     my ( $c, $class, $action, $err ) = @_;
 
+    my $namespace = $action->namespace;
+
     if ( my $handler =
-        ( $c->get_actions( "access_denied", $action->namespace ) )[-1] )
+        ( $c->get_actions( "access_denied", $namespace ) )[-1] )
     {
         local $c->{_acl_forcibly_allowed} = undef;
 
-        eval { $c->detach( $handler, [$action, $err] ) };
+        (my $path = $handler->reverse) =~ s!^/?!/!;
+
+        eval { $c->detach( $path, [$action, $err] ) };
 
         return 1 if $c->{_acl_forcibly_allowed};
 
