@@ -19,8 +19,9 @@ sub bar : Local {
 }
 
 sub gorch : Local {
-    my ( $self, $c ) = @_;
+    my ( $self, $c, $frozjob ) = @_;
     $c->res->body( $c->res->body . "gorch");
+    $c->res->body( $c->res->body . "&frozjob=$frozjob");
 }
 
 sub end : Private {
@@ -32,8 +33,9 @@ sub end : Private {
 }
 
 sub access_denied : Private {
-    my ( $self, $c, $action ) = @_;
+    my ( $self, $c, $action, $error ) = @_;
 
+    $c->res->header( 'X-Catalyst-ACL-Param-Action' => $action->reverse, 'X-Catalyst-ACL-Param-Error' => $error );
     $c->res->body( join " ", "handled", $c->res->body );
 
     $c->stash->{denied} = 1;
